@@ -1,17 +1,19 @@
 from flask_marshmallow import Marshmallow
 
+ma = Marshmallow()
 
-class PaginationSchema:
+
+class PaginationSchema(ma.SQLAlchemyAutoSchema):
     # global schema_object
     schema_object = None
-    ma = Marshmallow()
+    marsh = ma
 
-    def __init__(self, ma, app, schema_object):
+    def __init__(self, mar, app, schema_object):
         self.schema_object = schema_object
-        self.ma = ma
-        self.ma.init_app(app)
-
+        self.marsh = mar
+        self.marsh.init_app(app)
 
     class Meta:
         fields = ('has_prev', 'has_next', 'next_num', 'page', 'pages', 'per_page', 'prev_num', 'total', 'items')
-    items: ma.List(ma.Nested(schema_object))
+
+    items: marsh.List(marsh.Nested(schema_object))
